# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.0] - 2022-04-12
### Added
- add `djplus` command to generate the project.

## [0.1.0] - 2022-04-09
Initial release

[1.0.0]: https://github.com/githashem/djplus/compare/v0.1.0...v1.0.0
[0.1.0]: https://github.com/githashem/djplus/releases/tag/v0.1.0
